@@ -39,7 +39,7 @@ I wish to thank the following people for their input:
 
 '''
 
-__version__ = '1.1.0'
+__version__ = '1.1.1'
 
 
 import warnings
@@ -580,7 +580,8 @@ class Network(IP):
         '''
         warnings.warn('%s.in_network is deprecated, use check_collision in '
                       'stead' % (self.__class__.__name__,),
-                      DeprecationWarning)
+                      DeprecationWarning,
+                      stacklevel=2)
         other = Network(other)
         return self.network_long() <= other.network_long() <= self.broadcast_long()
 
@@ -590,7 +591,7 @@ class Network(IP):
         '''
         other = Network(other)
         return self.network_long() <= other.network_long() <= self.broadcast_long() or \
-            other.network_long() <= self.network_long() <= self.broadcast_long()
+            other.network_long() <= self.network_long() <= other.broadcast_long()
 
     def __contains__(self, ip):
         '''
@@ -601,7 +602,7 @@ class Network(IP):
         >>> '192.168.2.42' in Network('192.0.2.0/24')
         False
         '''
-        return self.in_network(ip)
+        return self.check_collision(ip)
 
     def __lt__(self, other):
         return self.size() < IP(other).size()
